@@ -1,20 +1,9 @@
 import sys
 import types
-import dill
+import tibidi.pickler as pickler
 from contextlib import contextmanager
 from tibidi.dumper import DEFAULT_DUMP_NAME
 
-class Dummy:
-    def __init__(self, name, module):
-        self._name = name
-        self._module = module
-
-    def __repr__(self):
-        return f'<dummy {self._name!r} from {self._module!r}>'
-
-    def __iter__(self):
-        yield
-
 
 class ModuleStub(types.ModuleType):
     def __init__(self, fullname):
@@ -24,7 +13,10 @@ class ModuleStub(types.ModuleType):
         self.__loader__ = self
 
     def __getattr__(self, name):
-        return Dummy(name, self.__name__)
+        return ModuleStub(f'{self.__name__}.{name}')
+
+    def __iter__(self):
+        yield from ()
 
 
 class ModuleStubFinder:
@@ -58,5 +50,5 @@ def load(filename: str = DEFAULT_DUMP_NAME) -> dict:
     """
     with DummyModuleFactory():
         with open(filename, 'rb') as f:
-            return dill.load(f)
+            return pickler.load(f)
 
